@@ -5,7 +5,7 @@ use Moo 1.003;
 use Elasticsearch::Util qw(parse_params load_plugin);
 use namespace::clean;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 my %Default_Plugins = (
     client      => [ 'Elasticsearch::Client',       'Direct' ],
@@ -71,81 +71,27 @@ DEPRECATION
 
 =head1 NAME
 
-Elasticsearch - The official client for Elasticsearch
+Elasticsearch - DEPRECATED: The official client for Elasticsearch
 
 =head1 VERSION
 
-version 1.04
-
-=head1 SYNOPSIS
-
-    use Elasticsearch;
-
-    # Connect to localhost:9200:
-
-    my $e = Elasticsearch->new();
-
-    # Round-robin between two nodes:
-
-    my $e = Elasticsearch->new(
-        nodes => [
-            'search1:9200',
-            'search2:9200'
-        ]
-    );
-
-    # Connect to cluster at search1:9200, sniff all nodes and round-robin between them:
-
-    my $e = Elasticsearch->new(
-        nodes    => 'search1:9200',
-        cxn_pool => 'Sniff'
-    );
-
-    # Index a document:
-
-    $e->index(
-        index   => 'my_app',
-        type    => 'blog_post',
-        id      => 1,
-        body    => {
-            title   => 'Elasticsearch clients',
-            content => 'Interesting content...',
-            date    => '2013-09-24'
-        }
-    );
-
-    # Get the document:
-
-    my $doc = $e->get(
-        index   => 'my_app',
-        type    => 'blog_post',
-        id      => 1
-    );
-
-    # Search:
-
-    my $results = $e->search(
-        index => 'my_app',
-        body  => {
-            query => {
-                match => { title => 'elasticsearch' }
-            }
-        }
-    );
-
-    # Cluster requests:
-
-    $info        = $e->cluster->info;
-    $health      = $e->cluster->health;
-    $node_stats  = $e->cluster->node_stats
-
-    # Index requests:
-
-    $e->indices->create(index=>'my_index');
-    $e->indices->delete(index=>'my_index');
+version 1.05
 
 =head1 DESCRIPTION
 
+B<THIS MODULE IS DEPRECATED.>
+
+******************************************************************************
+
+Because of the name clash between C<ElasticSearch.pm> and C<Elasticsearch.pm>
+the official Perl client is now called: L<Search::Elasticsearch>.
+
+See L<https://github.com/elasticsearch/elasticsearch-perl/issues/20> for details.
+
+This distribution will be removed from CPAN in 2015. Please update your code.
+
+******************************************************************************
+
 L<Elasticsearch> is the official Perl client for Elasticsearch, supported
 by L<elasticsearch.com|http://www.elasticsearch.com>.  Elasticsearch
 itself is a flexible and powerful open source, distributed real-time
@@ -160,9 +106,7 @@ default, which is not backwards compatible with the 0.90 branch.
 If you need to talk to a version of Elasticsearch before 1.0.0,
 please use L<Elasticsearch::Client::0_90::Direct> as follows:
 
-    $es = Elasticsearch->new(
-        client => '0_90::Direct'
-    );
+    $es = Elasticsearch->new( client => '0_90::Direct' );
 
 =head2 Motivation
 
@@ -419,7 +363,7 @@ See :
 
 =item * L<Elasticsearch::Client::Direct> (default, for 1.0 branch)
 
-= item * L<Elasticsearch::Client::0_90::Direct> (for 0.90 branch)
+=item * L<Elasticsearch::Client::0_90::Direct> (for 0.90 branch)
 
 =item * L<Elasticsearch::Client::Compat> (for migration from the old
 L<ElasticSearch> module)
@@ -447,6 +391,8 @@ See:
 
 =item * L<Elasticsearch::Cxn::HTTPTiny> (default)
 
+=item * L<Elasticsearch::Cxn::Hijk>
+
 =item * L<Elasticsearch::Cxn::LWP>
 
 =item * L<Elasticsearch::Cxn::NetCurl>
@@ -482,8 +428,7 @@ appropriate. See:
 
 =head2 C<logger>
 
-The class the use for logging events and tracing HTTP
-requests/responses.  See:
+The class to use for logging events and tracing HTTP requests/responses.  See:
 
 =over
 
@@ -677,5 +622,5 @@ This is free software, licensed under:
 
 __END__
 
-# ABSTRACT: The official client for Elasticsearch
+# ABSTRACT: DEPRECATED: The official client for Elasticsearch
 
