@@ -1,5 +1,5 @@
 package Elasticsearch::Role::API;
-$Elasticsearch::Role::API::VERSION = '1.04';
+$Elasticsearch::Role::API::VERSION = '1.05';
 use Moo::Role;
 
 use Elasticsearch::Util qw(throw);
@@ -619,7 +619,11 @@ sub api {
         method => "POST",
         parts  => {},
         paths  => [ [ {}, "_cluster", "reroute" ] ],
-        qs => [ "dry_run", "filter_metadata", "master_timeout", "timeout" ],
+        qs     => [
+            "dry_run",         "explain",
+            "filter_metadata", "master_timeout",
+            "timeout",
+        ],
     },
 
     'cluster.state' => {
@@ -1321,7 +1325,7 @@ Elasticsearch::Role::API - This class contains the spec for the Elasticsearch AP
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 DESCRIPTION
 
