@@ -1,5 +1,5 @@
 package Elasticsearch::Role::CxnPool::Static;
-$Elasticsearch::Role::CxnPool::Static::VERSION = '1.04';
+$Elasticsearch::Role::CxnPool::Static::VERSION = '1.05';
 use Moo::Role;
 with 'Elasticsearch::Role::CxnPool';
 requires 'next_cxn';
@@ -39,7 +39,16 @@ Elasticsearch::Role::CxnPool::Static - A CxnPool role for connecting to a remote
 
 =head1 VERSION
 
-version 1.04
+version 1.05
+
+=head1 METHODS
+
+=head2 C<schedule_check()>
+
+    $cxn_pool->schedule_check
+
+Forces a ping on each cxn in L<cxns()|Elasticsearch::Role::CxnPool/cxns()>
+before the next time that cxn is used for a request.
 
 =head1 AUTHOR
 
@@ -58,3 +67,4 @@ This is free software, licensed under:
 __END__
 
 # ABSTRACT: A CxnPool role for connecting to a remote cluster with a static list of nodes.
+
