@@ -1,5 +1,5 @@
 package Elasticsearch::Scroll;
-$Elasticsearch::Scroll::VERSION = '1.04';
+$Elasticsearch::Scroll::VERSION = '1.05';
 use Moo;
 use Elasticsearch::Util qw(parse_params);
 use namespace::clean;
@@ -19,15 +19,16 @@ sub BUILDARGS {
     my $total = $results->{hits}{total};
 
     return {
-        es         => $es,
-        scroll     => $scroll,
-        facets     => $results->{facets},
-        suggest    => $results->{suggest},
-        took       => $results->{took},
-        total_took => $results->{took},
-        total      => $total,
-        max_score  => $results->{hits}{max_score},
-        _buffer    => $results->{hits}{hits},
+        es           => $es,
+        scroll       => $scroll,
+        aggregations => $results->{aggregations},
+        facets       => $results->{facets},
+        suggest      => $results->{suggest},
+        took         => $results->{took},
+        total_took   => $results->{took},
+        total        => $total,
+        max_score    => $results->{hits}{max_score},
+        _buffer      => $results->{hits}{hits},
         $total
         ? ( _scroll_id => $results->{_scroll_id} )
         : ( is_finished => 1 )
@@ -109,7 +110,7 @@ Elasticsearch::Scroll - A helper module for scrolled searches
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
@@ -345,6 +346,10 @@ The total number of documents that matched your query.
 
 The maximum score of any documents in your query.
 
+=head2 C<aggregations>
+
+Any aggregations that were specified, or C<undef>
+
 =head2 C<facets>
 
 Any facets that were specified, or C<undef>
